CGRect

Struct CGRect 

#[repr(C)]
pub struct CGRect { pub origin: CGPoint, pub size: CGSize, }
The location and dimensions of a rectangle.

See documentation.

Fields

origin: CGPoint

The coordinates of the rectangle’s origin.

size: CGSize

The height and width of the rectangle.

Implementations

Source

impl CGRect

Rectangle construction.

pub const ZERO: Self

A rectangle with zero origin and size.

pub const NULL: Self

The null rectangle, representing an invalid value.

See documentation.

pub const INFINITE: Self

A rectangle that has infinite extent.

See documentation.

pub const fn new( x: CGFloat, y: CGFloat, width: CGFloat, height: CGFloat, ) -> Self

Returns a rectangle with the given components.

This is equivalent to CGRectMake.

pub const fn from_i16s(x: i16, y: i16, width: i16, height: i16) -> Self

Returns a rectangle with the given components losslessly converted to CGFloats.

pub const fn from_parts(origin: CGPoint, size: CGSize) -> Self

Returns a rectangle with the specified parts.

Source

impl CGRect

Get and set rectangle properties.

pub const fn x(&self) -> CGFloat

Returns the x-coordinate of self.

pub const fn y(&self) -> CGFloat

Returns the y-coordinate of self.

pub const fn width(&self) -> CGFloat

Returns the width of self.

pub const fn height(&self) -> CGFloat

Returns the height of self.

pub const fn with_x(self, x: CGFloat) -> Self

Returns self with an updated x-coordinate.

pub const fn with_y(self, y: CGFloat) -> Self

Returns self with an updated y-coordinate.

pub const fn with_width(self, width: CGFloat) -> Self

Returns self with an updated width.

pub const fn with_height(self, height: CGFloat) -> Self

Returns self with an updated height.

pub fn set_x(&mut self, x: CGFloat) -> &mut Self

Updates the x-coordinate of self in-place.

pub fn set_y(&mut self, y: CGFloat) -> &mut Self

Updates the y-coordinate of self in-place.

pub fn set_width(&mut self, width: CGFloat) -> &mut Self

Updates the width of self in-place.

pub fn set_height(&mut self, height: CGFloat) -> &mut Self

Updates the height of self in-place.

Source

impl CGRect

Get rectangle bounds.

pub fn min_x(&self) -> CGFloat

Returns the smallest value for the x-coordinate of self.

See documentation.

pub fn min_y(&self) -> CGFloat

Returns the smallest value for the y-coordinate of self.

See documentation.

pub fn mid_x(&self) -> CGFloat

Returns the center value for the x-coordinate of self.

See documentation.

pub fn mid_y(&self) -> CGFloat

Returns the center value for the y-coordinate of self.

See documentation.

pub fn max_x(&self) -> CGFloat

Returns the largest value for the x-coordinate of self.

See documentation.

pub fn max_y(&self) -> CGFloat

Returns the largest value for the y-coordinate of self.

See documentation.

Source

impl CGRect

pub fn is_empty(&self) -> bool

Returns true if self has zero width or height, or is a null rectangle.

See documentation.

pub fn is_null(&self) -> bool

Returns true if self is a null rectangle.

See documentation.

pub fn is_infinite(&self) -> bool

Returns true if self is infinite.

See documentation.

pub fn contains_point(&self, point: CGPoint) -> bool

Returns true if self contains point.

See documentation.

pub fn contains_rect(&self, other: &Self) -> bool

Returns true if self contains other.

See documentation.

pub fn intersects(&self, other: &Self) -> bool

Returns true if self intersects other.

See documentation.

pub fn standardize(self) -> Self

Returns self with a positive width and height.

See documentation.

pub fn integral(self) -> Self

Returns the smallest rectangle that results from converting the values of self to integers.

See documentation.

pub fn apply(self, transform: CGAffineTransform) -> Self

Returns the result of applying an affine transformation to self.

See documentation.

pub fn offset(self, dx: CGFloat, dy: CGFloat) -> Self

Returns self with its origin offset.

See documentation.

pub fn inset(self, dx: CGFloat, dy: CGFloat) -> Self

Returns a rectangle that is smaller or larger than self, with the same center point.

See documentation.

pub fn divide(self, amount: CGFloat, edge: CGRectEdge) -> (Self, Self)

Returns two rectangles by dividing self.

Together edge and amount define a line (parallel to the specified edge of the rectangle and at the specified distance from that edge) that divides the rectangle into two component rectangles.

The returned tuple consists of:

  • slice: The component rectangle nearest the edge of the original rectangle specified by edge, with width equal to amount.

  • remainder: The component rectangle equal to the remaining area of the original rectangle not included in the slice rectangle.

See documentation.

pub fn union(self, other: Self) -> Self

Returns the smallest rectangle that contains self and other.

See documentation.

pub fn intersection(self, other: Self) -> Self

Returns the intersection of self and other.

See documentation.