AEEventID

Struct AEEventID 

#[repr(transparent)]
pub struct AEEventID(pub FourCharCode);
Specifies the event ID of an Apple event.

Apple events are identified by their event class and eventID attributes. The event ID is the attribute that identifies a particularApple event within its event class. In conjunction with the event class, the event ID uniquely identifies the Apple event and communicates what action the Apple event should perform.

See documentation.

Tuple Fields

0: FourCharCode

Implementations

Source

impl AEEventID

pub const fn from_int(int: u32) -> Self

Returns an instance from the integer value.

pub const fn from_chars(chars: [u8; 4]) -> Self

Returns an instance from the 4-character code.

pub const fn into_int(self) -> u32

Returns this descriptor’s integer value.

pub const fn into_chars(self) -> [u8; 4]

Returns this descriptor’s 4-character code.

Source

impl AEEventID

Event IDs for AEEventClass::CORE.

pub const OPEN_APPLICATION: Self

Event that causes the application to quit.

Value: oapp.

See documentation.

pub const OPEN_DOCUMENTS: Self

Event that provides an application with a list of documents to open. Sent, for example, when a selects one or more documents for your application in the Finder and double-clicks them.

Value: odoc.

See documentation.

pub const PRINT_DOCUMENTS: Self

Event that provides an application with a list of documents to print.

Value: pdoc.

See documentation.

pub const OPEN_CONTENTS: Self

Event that provides an application with dragged content, such as text or an image. Sent, for example, when a user drags an image file onto your application’s icon in the Dock. The application can use the content as desired—for example, if no document is currently open, it might open a new document and insert the provided text or image.

Value: ocon.

See documentation.

pub const QUIT_APPLICATION: Self

Event that causes the application to quit.

Value: quit.

See documentation.

pub const ANSWER: Self

Event that is a reply Apple event.

Value: ansr.

See documentation.

pub const APPLICATION_DIED: Self

Event sent by the Process Manager to an application that launched another application when the launched application quits or terminates.

Value: obit.

See documentation.

pub const SHOW_PREFERENCES: Self

Event sent by the macOS to a process when the user chooses the Preferences item for that process.

Value: pref.

See documentation.